% eigfields  Resonance fields by the eigenfield method 
%
%   B = eigfields(Sys, Par, Ori)
%   B = eigfields(Sys, Par, Ori, Opt)
%   [B, Int] = eigfields(...)
%
%   Calculates all resonance fields of spin system
%   Sys solving a generalized eigenvalue problem
%   in Liouville space together with transition pro-
%   babilitites.
%
%   Input:
%   - Sys: spin system specification structure
%   - Par: structure with fields
%        mwFreq - spectrometer frequency [GHz]
%        Detection - 'parallel' or 'perpendicular' (default)
%          direction of detection relative to static field
%        Range - [Bmin Bmax] If set, compute only eigenfields
%           between Bmin and Bmax. [mT]
%   - Ori: 2xn or 3xn array of orientation angles [radians]
%        columns contain [phi;theta] or [phi;theta;chi].
%        If chi is omitted, transition probabilities are
%        integrated over chi.
%   - Opt: options structure with fields
%        Threshold - if set, return only transitions with
%          relative intensity above Threshold. Works only if
%          transition intensities are returned.
%
%   Output:
%   - B:   cell array of all resonance fields [mT]
%   - Int: transition intensities [MHz^2/mT^2]

