% garlic    Simulates isotropic and fast-motion cw EPR spectra 
%
%   garlic(Sys,Exp)
%   spec = garlic(Sys,Exp)
%   [B,spec] = garlic(Sys,Exp)
%
%   Computes the solution cw EPR spectrum of systems with
%   an electron and arbitrary numbers of nuclear spins.
%
%   Input:
%     Sys.g            isotropic g factor or 3 principal values of g
%     Sys.Nucs         string with comma-separated list of isotopes
%     Sys.n            vector of number of equivalent nuclei (default all 1)
%     Sys.A            vector of hyperfine couplings [MHz]
%     Sys.lw           vector with FWHM line widths [mT]
%                       1 element:   LorentzianFWHM
%                       2 elements: [LorentzianFWHM GaussianFWHM]
%
%     Sys.tcorr        correlation time for fast-motion linewidths [s]
%                      If omitted or set to zero, the isotropic spectrum
%                      is computed.
%
%     Exp.mwFreq       spectrometer frequency [GHz]
%     Exp.CenterSweep  [centerField sweepRange] in mT
%     Exp.Range        [minField maxField] in mT
%
%          Exp.Range is only used if Exp.CenterSweep is not given.
%          If both Exp.CenterField and Exp.Range are omitted, the
%          magnetic field range is determined automatically.
%
%     Exp.Harmonic     detection harmonic (0, 1, or 2), default 1
%     Exp.nPoints      number of points (default 1024)
%
%   Output:
%     B                magnetic field axis [mT]
%     spec             spectrum [arbitrary units]
%
%     If no output parameter is specified, the simulated spectrum
%     is plotted.
%
%   Example isotropic spectrum
%
%     Sys = struct('g',2,'Nucs','1H,14N','A',[30,40],'n',[3 4]);
%     Sys.lw = 0.1;
%     Exp = struct('mwFreq',9.7,'nPoints',1e4);
%     garlic(Sys,Exp);
%
%   Example fast-motion spectrum
%
%     A = mt2mhz([5.8 5.8 30.8]/10);
%     Sys = struct('g',[2.0088 2.0061 2.0027],'Nucs','14N','A',A);
%     Sys.tcorr = 5e-9;
%     Exp = struct('mwFreq',9.5);
%     garlic(Sys,Exp);

