% ENDOR orientation selection in a powder
%=====================================================================
clear all, close all

% Definition of the spin system
Sys = struct('S',1/2,'g',[2.3,2.1,2]);
Sys = nucspinadd(Sys,'1H',[3,6,2]);
Sys.HStrain = [1 1 1]*180;     % MHz
Sys.lwEndor = 0.1;    % MHz

% ENDOR simulations
EndorExp = struct('mwFreq',9.5,'ExciteWidth',50);
Opt = struct('nKnots',21);

B0 = 295:5:340;            % magnetic field, mT
nuH = larmorfrq('1H',B0);  % nuclear Larmor frequencies, MHz

for k = 1:numel(B0)   % loop over all field values
  EndorExp.Field = B0(k);
  EndorExp.Range = nuH(k) + [-4 4];  % rf range in MHz, centred aroung Larmor frequency
  [x,y] = salt(Sys,EndorExp,Opt);
  y = y/sum(y)/(x(2)-x(1));          % normalize to unit area
  EndorSpec(k,:) = y;
end

% Stack plot
distance = 0.5;
for k = 1:numel(B0)
  plot(x,EndorSpec(k,:)+k*distance);
  hold on
end
hold off

xlabel('frequency [MHz]');
title('ENDOR spectra');
axis tight; grid on
