% User-supplied orientation pre-selection
%======================================================================
clear all, close all

% Definition of the spin system
System = struct('S',1/2,'g',[2 2 2.2],'Nucs','63Cu,1H',...
  'A',[[40 40 400];4+[-1 0 2]*1.5]);
System.lwEndor = 0.02;

% Definition of the experiment
Experiment = struct('Range',[-1 1]*5+13.3,'mwFreq',9.5,'ExciteWidth',50);
Experiment.Field = 310;

% ENDOR simulation options
Options = struct('Verbosity',1,'nKnots',91);
Options.Nuclei = 2;   % compute only 1H ENDOR

% ======= The important line ==============
Options.OriWeights = orisel(System,Experiment,Options);
% orisel(...) computes the orientation selectivity
% for the field/frequency values. The resulting weights
% are stored in Options.OriWeights, which are used by
% salt(...). This saves salt() the trouble of doing the
% orientation selection.

% In the following we only change the 1H coupling,
% which does not affect the orientation selection.
% As a consequence, salt() is much faster with
% Options.OriWeights given.

rho = linspace(0.01,1/3,10);
for k = 1:numel(rho)
  % change rhombicity of hyperfine coupling
  System.A(2,:) = 4 + [-1-rho(k) -1+rho(k) 2]*1.5;
  [x,y(k,:)] = salt(System,Experiment,Options);
end
y = y/max(y(:));  % normalize to amplitude 1

% Prepare stack plot
shift = 0.2;
for k=1:size(y,1)
  y(k,:) = y(k,:) - shift*k;
end

plot(x,y,'b');

xlabel('frequency [MHz]');
title('ENDOR spectra');
axis tight;
