% Basic example of fitting using Matlab's fminsearch
%====================================================================
% Note that this is not a Matlab script, but a Matlab function
% containing subfunctions.
function basicfit

% Load experimental data into global data structure
global Data;
Data = getspectrum;

% Options for the optimization function
fitOpt = optimset;
fitOpt.Display = 'iter';

% Starting values for the parameters (see subfunction simulate)
x0(1) = 1.95; % g_y
x0(2) = 1; % lw in mT

% Fitting with simplex method
x_optim = fminsearch(@fittingerror,x0,fitOpt);

% Simulate and plot result
spcstart = simulate(x0); spcstart = spcstart/max(spcstart);
spcopt = simulate(x_optim); spcopt = spcopt/max(spcopt);
plot(Data.B,Data.spc,'b',Data.B,spcstart,'r',Data.B,spcopt,'g');
legend('data','start','fitted');
xlabel('magnetic field [mT]');

%====================================================================
% Function that computes the fitting error
function err = fittingerror(x)

spcsim = simulate(x);
global Data; % Connect to experimental data structure
Deviation = spcsim/max(spcsim) - Data.spc/max(Data.spc);
err = sqrt(mean(Deviation.^2));


%====================================================================
% Function that simulates the spectrum
function simspc = simulate(x)

global Data; % Connect to experimental data structure
Exp = struct('mwFreq',Data.mw,'Range',[min(Data.B) max(Data.B)]);
Sys = struct('g',[1.9 x(1) 2.1],'lw',x(2));
simspc = pepper(Sys,Exp);


%====================================================================
% Function to load and pre-process experimental data
% Replace the code below with your code
function Data = getspectrum

Sys = struct('g',[1.9 2 2.1],'lw',2);
Exp = struct('mwFreq',9.5,'Range',[300 380]);
[Data.B,Data.spc] = pepper(Sys,Exp);

Noise = 0.1*(rand(size(Data.spc))-0.5);
Data.spc = Data.spc/max(Data.spc) + Noise;
Data.mw = Exp.mwFreq;
