% Two-pulse echo
%==========================================================================

clear all, close all

n = 300; % signal length
dt = .005; % step time [s]
FWHM = 20; % line width [MHz]
tau = .7; % interpulse distance [s]

Sx = sop(1/2,'x');
Sy = sop(1/2,'y');
Sz = sop(1/2,'z');

offset = 1.2*FWHM*linspace(-1,1,200);
weights = gaussian(offset,0,FWHM);
tp = 0:.020:.180; % pulse length [s]

% We compute a set of 2-pulse-echo signals, 
% differing in the length of the pulses used.
% The static Hamiltonian is not neglected during
% the pulse.

signal = zeros(n,length(tp));
for p = 1:length(tp)
  for k = 1:length(offset)
    Ham0 = offset(k)*Sz;
    Pulse = expm(-i*(pi/2*Sx+2*pi*tp(p)*Ham0));
    TauEvol = expm(-2i*pi*tau*Ham0);
    U = Pulse^2*TauEvol*Pulse;
    signal(:,p) = signal(:,p) + ...
      weights(k)*real(evolve(-U*Sz*U',Sy,Ham0,n,dt));
  end
end

% Result: The longer the pulses, the broader the
% echo.

plot((0:n-1)*dt,signal,'b');
title('The primary ESE depending on the pulse length');
xlabel('time after the pi pulse [s]');
ylabel('echo signal');

% end
