% Comparison between fast- and slow-motion simulation algorithms
%==========================================================================
clear all, close all

% Parameters
%----------------------------------------------------
tcorr = 1e-9;  % seconds
lw = 0.1;      % mT
g = [2.0088, 2.0061, 2.0027];
A = mt2mhz([5.8, 5.8, 30.8]/10);   % G -> MHz

Nx = struct('g',g,'Nucs','14N','A',A);
Par = struct('mwFreq',9.5,'CenterSweep',[338, 10]);

% Fast-motion
Nx.lw = lw;
Nx.tcorr = tcorr;

% Slow-motion
Dyn.tcorr = tcorr;
Dyn.lw = mt2mhz(lw,mean(g)); % mT -> MHz

% Simulation
%----------------------------------------------------
[B,spc_s] = chili(Nx,Dyn,Par);
[B,spc_f] = garlic(Nx,Par);

% Graphical rendering
%----------------------------------------------------
plot(B,spc_s/max(spc_s),'k',B,spc_f/max(spc_f),'r');
xlabel('magnetic field [mT]');
legend('chili','garlic');
axis tight
title(sprintf('correlation time: %g ns',Dyn.tcorr/1e-9));
