% Effect of Heisenberg exchange in a nitroxide sample
%==========================================================================
clear all, close all

% Nitroxide and experimental parameters
%--------------------------------------------------------------------------
Nx = struct('g',[2.0088, 2.0061, 2.0027],'Nucs','14N','A',[16 16 86]);
Par = struct('mwFreq',9.5,'CenterSweep',[338, 10]);
Dyn = struct('tcorr',0.2e-9,'lw',0.3);

% Loop over range of exchange frequencies, simulation
%--------------------------------------------------------------------------
ExchangeFreq = 10.^linspace(6,9,10); % in Hertz
for k = 1:numel(ExchangeFreq)
  Dyn.Exchange = ExchangeFreq(k);
  [B,y] = chili(Nx,Dyn,Par);
  % Normalize spectra and stack on top of previous
  spc(k,:) = y/max(y) + k;
end

% Graphical rendering
%--------------------------------------------------------------------------
plot(B,spc);
xlabel('magnetic field [mT]');
axis tight
