% A Cu(II) complex at S, X and Q band
%==========================================================================
clear all, close all

% set up spin systems for 63Cu and 65Cu
A63 = [50 50 400];
A65 = A63*nucgval('65Cu')/nucgval('63Cu');

Sys63 = struct('g',[2 2 2.2],'lw',1);
Sys63 = nucspinadd(Sys63,'63Cu',A63);

Sys65 = struct('g',[2 2 2.2],'lw',1);
Sys65 = nucspinadd(Sys65,'63Cu',A65);

% set spectrometer frequency for S band, X band and Q band experiments
% magnetic field range is set automatically
ParS = struct('mwFreq',2);
ParX = struct('mwFreq',9.5);
ParQ = struct('mwFreq',34);

% set up options
Opt = [];

% simulate all spectra
[Bs,spec63S] = pepper(Sys63,ParS,Opt); [Bs,spec65S] = pepper(Sys65,ParS,Opt);
[Bx,spec63X] = pepper(Sys63,ParX,Opt); [Bx,spec65X] = pepper(Sys65,ParX,Opt);
[Bq,spec63Q] = pepper(Sys63,ParQ,Opt); [Bq,spec65Q] = pepper(Sys65,ParQ,Opt);

% sum up spectra of isotopes
alpha = nucabund('63Cu');
specS = alpha*spec63S + (1-alpha)*spec65S;
specX = alpha*spec63X + (1-alpha)*spec65X;
specQ = alpha*spec63Q + (1-alpha)*spec65Q;

% display
subplot(3,1,1); plot(Bs,specS); axis tight; title('S band');
subplot(3,1,2); plot(Bx,specX); axis tight; title('X band');
subplot(3,1,3); plot(Bq,specQ); axis tight; title('Q band');
xlabel('magnetic field [mT]');
