% High-spin iron(III) spectrum of lipoxygenase-1, E/D distribution
%==========================================================================
% see Gaffney et al, Biophys.J. 64, 773-783 (1993)

% The spectrum contains a rhombic and a nearly axial component
% (data from Table 2)
% D = 1.7 cm^-1 for all
% rhombic   E/D = 0.065    sigma(E/D) = 0.011
% axial I   E/D = 0.0175   sigma(E/D) = 0.008
% axial II  E/D = 0.0150   sigma(E/D) = 0.004
% additional linewidth 150 MHz

D = 1.7; % cm^-1
D = D*100*clight/1e6; % -> MHz

Exp = struct('mwFreq',9.5,'Range',[0 400],'nPoints',2048);
Opt = struct('nKnots',121,'Output','separate');

% Rhombic component
%---------------------------------------------------------
Sys1.S = 5/2;
Sys1.g = [2 2 2];
Sys1.HStrain = [1 1 1]*150;

EoverD = 0.065;
E = EoverD*D;
Sys1.D = [-1 -1 2]*D/3 + [1 -1 0]*E;

% Gaussian distribution of E/D with half-width 0.011
Sys1.DStrain = [0 2*0.011*D];

[x,y1] = pepper(Sys1,Exp,Opt);

% Nearly axial component (II)
%---------------------------------------------------------
Sys2 = Sys1;
EoverD = 0.0150;
E = EoverD*D;
Sys2.D = [-1 -1 2]*D/3 + [1 -1 0]*E;
Sys2.DStrain = [0 2*0.004*D];

[x,y2] = pepper(Sys2,Exp,Opt);

% Total spectrum
%----------------------------------------------------------
alpha = 0.07;
yTotal = (1-alpha)*sum(y1) + alpha*sum(y2);

% Plot results
%----------------------------------------------------------
subplot(3,1,1);
plot(x,y1);
xlabel('magnetic field [mT]');
title('Transitions of rhombic component');

subplot(3,1,2);
plot(x,y2);
xlabel('magnetic field [mT]');
title('Transitions of nearly axial component');

subplot(3,1,3);
plot(x,yTotal);
xlabel('magnetic field [mT]');
title('Total spectrum');

% end
