% An planar Cu(II) centre in a nematic liquid crystal phase
%==========================================================================
% The molecule is assumed to be planar, with the z axis
% of the reference frame perpendicular to the plane, just
% as in, e.g., CuTPP.

clear all, close all

% Only the 63Cu isotopomer is simulated
Sys = struct('S',1/2,'g',[2 2 2.2],'lw',1);
Sys = nucspinadd(Sys,'63Cu',[50 50 400]);

% Experimental parameters
Par = struct('mwFreq',9.5,'Range',[280 350]);

% Simulation options
Opt = [];

% (1) Powder spectrum
[B,spec1] = pepper(Sys,Par,Opt);
% (2) Nematic liquid crystal phase, high order
Par.Nematic = 20*pi/180;
[B,spec2] = pepper(Sys,Par,Opt);
% (3) Nematic liquid crystal phase, lower order
Par.Nematic = 70*pi/180;
[B,spec3] = pepper(Sys,Par,Opt);


plot(B,spec1,'k',B,spec2,'g',B,spec3,'r')
legend('powder','high nematic order','low nematic order');
