% Single-crystal spectra of triplet with non-equilibrium populations
%===================================================================
clear all,clf
%  
% Experimental parameters and simulation options
%------------------------------------------------------------------
Exp = struct('mwFreq',9.7,'Range',[0 450],'Harmonic',0);

% Populations of the three zero-field levels
% (is then normalized internally by EasySpin)
Exp.Temperature = [0 1 0];

% Orientation of the magnetic field in the molecular frame
% Change this value to turn the crystal in the spectrometer.
Exp.Orientations = pi/180*[0;0];

Opt = struct('Verbosity',2)

% Defining two spin systems, one with axial and one with orthorhombic D
%-----------------------------------------------------------------------
D = 0.06;
E = D*0.1;
Sys = struct('S',1,'g',[2 2 2],'lw',5);
Sys1 = Sys;
Sys1.D = clight/1e4*[-D/3, -D/3, 2*D/3];
Sys2 = Sys;
Sys2.D = clight/1e4*[-D/3 + E, -D/3 - E, 2*D/3];

% Simulations & Graphical rendering
%-------------------------------------------------------------
subplot(3,2,1);
levelsplot(Sys1,Exp.Orientations,Exp.Range,Exp.mwFreq);
title('Axial D tensor');

subplot(3,2,3);
pepper(Sys1,Exp,Opt);

subplot(3,2,2);
levelsplot(Sys2,Exp.Orientations,Exp.Range,Exp.mwFreq);
title('Slightly orthorhombic D tensor');

subplot(3,2,4);
pepper(Sys2,Exp,Opt);

Exp.Orientations = [];

subplot(3,2,5);
pepper(Sys1,Exp,Opt);

subplot(3,2,6);
pepper(Sys2,Exp,Opt);
