% CF3 radical in gas matrix at low temperature
%==========================================================================
% see Edlund et al, Molecular Physics 32 (1976) 49
clear all, close all;

% Spin system with 3 19F nuclei
%--------------------------------------------------------------------
Sys = struct('Nucs','19F,19F,19F','lw',0.6);
Sys.g = [2.0042 2.0042 2.0024];

% Hyperfine coupling tensors
%--------------------------------------------------------------------
% 19F hyperfine coupling tensors: identical principal values
A = [224.3 244.0 734.4]; % in MHz
Sys.A = [A;A;A];
% ...but different orientations
beta = -17.8;
Sys.Apa = [0 beta 0; 0 beta 120; 0 beta -120]*pi/180;

% Other parameters
%--------------------------------------------------------------------
Exp = struct('mwFreq',9.27,'Range',[285 375]);
Opt.nKnots = 30;
Opt.Symmetry = 'D3d';

% Simulation and graphical rendering
%--------------------------------------------------------------------
pepper(Sys,Exp,Opt);
xlabel('magnetic field [mT]');
set(gca,'YTick',[]);
title(sprintf('CF3 radical, randomly oriented, %g GHz',Exp.mwFreq));
