% cw EPR as a multiphoton experiment
%==========================================================================
% This example illustrates the fact that the simple cw
% EPR line in reality is the result of overlap of many sidebands.
% See Kaelin et al, J.Magn.Reson. 160, 166-182 (2003)

clear all

wrf = 2*pi*(0.1*1e6); % Frequency of the modulation field [Hz]
w2 = 2*pi*(1*1e6); % Amplitude of the modulation field [Hz]
T2 = 1/(0.1*1e6); % Life time (inverse line width) [s]

N = 10000;

z = 2*w2/wrf;
kmax = z;
frequency = 2*kmax*wrf*linspace(-1,1,N);

spec = 0;
for k = -kmax:kmax
  Amplitude = besselj(-k,z)*(besselj(1-k,z)+besselj(-1-k,z));
  LineShape = T2./(1+(frequency-k*wrf).^2*T2^2);
  SideBand = Amplitude*LineShape;
  spec = spec + SideBand;
end

plot(frequency/1e6,spec);
xlabel('offset frequency [MHz]');
ylabel('amplitude [a.u.]');
