#!/usr/bin/perl -w

# .........................................................................
# This PERL script parses PDB files, splits the file into continous
# amino acid segments and attempts to make any changes necessary
# in order to make the file CHARMM compatible. 
# It is still necessary to check each PDB file. This is especially true
# for x-ray waters, which could end up as part of another segment file.
# I just don't feel like figuring out how to separate them out completely.
# ks, 5-17-2001
# .........................................................................

# Assign start values to variables 
$segidwat = " ";	# Initialize water segment ID value
$segid = 1;		# Start segment ID value at 1
$countsegid = 0;	# Start counter for segment ID values at 0
$resnum_new = 1;	# resnum_new = current residue number 
$resnum_old = 1;	# resid_old = previous residue number 
$rowlab_new = "ATOM  ";	# rowlab_new = current value of first column of pdb 
$rowlab_old = "ATOM  "; # rowlab_old = previous first column value
$ans = " ";		# ans is variable for user input during output file checking
$spaces = "      ";	# spaces = number of spaces to needed to put segid in correct columns
$watcount = 0;

# Get command line values
if ($#ARGV !=0) {
	die "Usage: $0 InFile\n"
}
$infile = $ARGV[0];	# infile = pdb file input at command line
($outfileroot, $outfileext) = split(/\./, $infile); #extract the root and the extension of input file
#$outfileroot = "maeda_tni_mtsl";
if ($outfileext eq "pdbx") {$outfileext = "pdb";}

# Verify that infile is of the correct format
if (! -r $infile) {
	die "Can't read input $infile\n";
}
if (! -f $infile) {
	die "Input $infile is not a plain text file\n";
}

# Validate files
# or statements "||" short circuit, so that if any ealy part
# evaluates as true, PERL does not bother checking the others
# Here if the file opens successfully we don't abort
open (INPUT,"<$infile") ||
	die "Can't input $infile $!";

# Read the first line of data from file to get starting
# residue number (it may be > 1)
# Close the file when done (otherwise current line is line 2)
read(INPUT, $newtext, 66, 0);
$resnum_old = substr($newtext, 22, 4); 
$resnum_new = substr($newtext, 22, 4); 
close (INPUT);

# Reopen the input file for reading
open (INPUT,"<$infile") ||
	die "Can't input $infile $!";

# Call subroutine to open new output file for the first PDB segment 
openoutfile($outfileroot, $segid, $outfileext);

# Read input file line by line
# If the line starts with either ATOM or HETATM then use it; otherwise move on
# If the line changes from ATOM to HETATM (or vis versa) or the residue number
# increases by more than 1, then open a new output file. Otherwise, continue
# writing lines to the same output file.

while (<INPUT>) {
	if (substr($_, 0, 3) eq "END" || substr($_, 0, 3) eq "TER") {
#		print OUTPUT $_,"\n";
		print OUTPUT "END","\n","\n";
		$segid++;
		$countsegid++;
		openoutfile($outfileroot, $segid, $outfileext);
	}
	if ((substr($_, 0, 4) eq "ATOM" || substr($_, 0, 6) eq "HETATM") && substr($_, 13, 4) ne "OT2 ") {
		$resnum_new = substr($_, 22, 4); 
		$rowlab_new = substr($_, 0, 6); 
		if ($rowlab_new eq $rowlab_old && ($resnum_new == $resnum_old || $resnum_new == $resnum_old + 1)
		    && (substr($_, 17, 4) ne "HOH " || substr($_, 17, 4) ne "TIP3")) { 
			output($_);		
		}
		elsif (substr($_, 17, 4) eq "HOH " || substr($_, 17, 4) eq "TIP3") {
			if ($watcount == 0) {
				print OUTPUT "END\n ";
				$segidwat = "_xwat";
				openxwatoutfile($outfileroot, $segid, $outfileext);
				output($_);
				$watcount = 1;
			}
			else {
				output($_);
			}
		}
		else {
			print OUTPUT "END\n ";
			close OUTPUT;
			$segid++;
			$countsegid++;
			openoutfile($outfileroot, $segid, $outfileext);	
			output($_);		
		}
	}
}

my $lastfile = $outfileroot . $segid . "." . $outfileext;
unlink $lastfile;

open (OUTPUT, ">numsegs") ||
        die "Can't open outfile $!";
print OUTPUT $countsegid." \n";
close OUTPUT;

# Subroutine output makes any changes needed to make the new PDB file
# CHARMM compatible and writes the line to the current output file
# THIS IS WHERE ANY CHANGES TO THE OUTPUT PDB FILE SHOULD BE MADE.

# All segment IDs are numbers taken from the $segid counter with 
# the exception of waters which get a segid of XWAT.

sub output($)
{
	chomp $_;
	$_ = substr($_, 0, 66);
	if (substr($_, 13, 7) eq "CD1 ILE") {substr($_, 13, 7, "CD  ILE");}
	if (substr($_, 0, 6) eq "HETATM") {substr($_, 0, 6, "ATOM  ");}
	if (substr($_, 13, 4) eq "HN1 ") {substr($_, 13, 4, "HT1 ");}
	if (substr($_, 13, 4) eq "HN2 ") {substr($_, 13, 4, "HT2 ");}
	if (substr($_, 13, 4) eq "HN3 ") {substr($_, 13, 4, "HT3 ");}
	if (substr($_, 13, 4) eq "OT1 ") {substr($_, 13, 4, "O   ");}
	if (substr($_, 13, 4) eq "HN  ") {substr($_, 13, 4, "H   ");}
	if (substr($_, 17, 4) eq "HOH " || substr($_, 17, 4) eq "TIP3") {
		substr($_, 17, 4, "TIP3");
		$xwatsegid = "XWAT";
		if (substr($_, 13, 4) eq "O   ") {substr($_, 13, 4, "OH2 ");}
		if (substr($_, 12, 4) eq "HH21") {substr($_, 12, 4, " H1 ");} 
		if (substr($_, 12, 4) eq "HH22") {substr($_, 12, 4, " H2 ");} 
		if (substr($_, 12, 4) eq "1HH2") {substr($_, 12, 4, " H1 ");} 
		if (substr($_, 12, 4) eq "2HH2") {substr($_, 12, 4, " H2 ");} 
		$_ = "$_$spaces$xwatsegid";
	}
	else {
		$_ = "$_$spaces$segid";
	}
	print OUTPUT $_,"\n";
	$resnum_old = $resnum_new;
	$rowlab_old = $rowlab_new;
}

sub openoutfile($$$)
{
my $outfile = $outfileroot . $segid . "." . $outfileext;

if (-e $outfile) {
	print STDERR "Output file $outfile exists!\n";
	until ($ans eq 'r' || $ans eq 'a' || $ans eq 'e') {
		print STDERR "replace, append or exit?";
		$ans = getc(STDIN);
	}
	if ($ans eq 'e') {exit}
}
if ($ans eq 'a') {$mode = '>>'}
else {$mode='>'}
open (OUTPUT, "$mode$outfile") ||
	die "Can't open $outfile $!";
$ans = " ";
}

sub openxwatoutfile($$$)
{
my $outfile = $outfileroot . $segidwat . "." . $outfileext;

if (-e $outfile) {
	print STDERR "Output file $outfile exists!\n";
	until ($ans eq 'r' || $ans eq 'a' || $ans eq 'e') {
		print STDERR "replace, append or exit?";
		$ans = getc(STDIN);
	}
	if ($ans eq 'e') {exit}
}
if ($ans eq 'a') {$mode = '>>'}
else {$mode='>'}
open (OUTPUT, "$mode$outfile") ||
	die "Can't open $outfile $!";
$ans = " ";
}
