function PD_demo(casetype)
%% Threr are four demos in the following to demonstrate the use of the DPD_pkg 
%% (Determination of Pair-Distance distribution package).
%%
%% The data files, which are included in the DPD_pkg and are required for
%% the following demons, are:
%%      BimodalSNR30.dat (simulated time-domain dipolar signal)
%%      BimodalSNR30expbal.dat (BimodalSNR30.dat + exp decay baseline)
%%
%% Before you implement the demos, please make sure that you have download
%% the Regularization Toolbox from following website and add it to your
%% Matlab search path.
%% http://www2.imm.dtu.dk/~pch/Regutools/index.html
%%
%%%% demo 1: We assume that the intermolecular interactions, i.e. the baseline,
%%%% have been manually removed from the time-domain data. With the simulated 
%%%% intramolecular signals stored in the file 'BimodalSNR30.dat', we perform 
%%%% Tikhonov Regularization to recover the P(r) from the data file. Use
%%%% the L-curve to estimate how well P(r) is recovered.
%% To do Tikhonov Regularization
%==> PD_demo('BimodalSNR30TKN');
%   (The program will plot out the results of the P(r) and the L-curve. The
%   solution vector P(r) is saved to the file, 'BimodalSNR30TKN.pr'. In
%   addition, the solution vector P(r) after the correction of the negative
%   potions is stored to the file, 'BimodalSNR30TKN.pr0'. Data in this .pr0 file
%   is all positive and will be used as the seed values for MEM calculations,
%   i.e. demo 2.)
%
%
%
%%%%
%%%% demo 2: In this demo, we show how to refine the Tikhonov result obtained 
%%%% in demon 1 by employing MEM calculation. 
%% To do MEM
%==> PD_demo('BimodalSNR30MEMwP0');
%   (This performs Maximum Entropy calculations without considering the
%   existence of baseline. 'BimodalSNR30TKN.pr0' is used as the seed
%   values for MEM calculations.
%   The solution P(r) obtained from MEM will be stored in two files, 
%   'BiomdalSNR30MEMwP0.pr' and 'BimodalSNR30MEMwP0.pr0'. This new .pr0 file
%   will be used in the demo 3)
%   Note:
%       It is strongly suggested that MEM must be seeded with a reasonable
%   initial solution vector P(r). Seeding MEM calculation with the PD_TKN
%   result would significantly reduce the calculation time and facilitate
%   convergence to the golbal minimum. To obtain a reasonable solution vector
%   for P(r), we suggest to manually subtract the baseline from S(t) and then do 
%   Tikhonov Regularization (PD_TKN) to obtain an estimated solution vector for 
%   P(r). MEM is very useful in refining P(r) for the cases where SNR is low.
%
%
%
%%%%
%%%% demo 3: The file 'BimodalSNR30expbal.dat' is assumed to be the raw
%%%% experimental DQC data, which includes intra- and inter-molecular
%%%% interactions together. This demo shows how to extract P(r) from such a
%%%% raw data using PD_MAXENT. We seed the calculation with
%%%% 'BimodalSNR30MEMwP0.pr0' (obtained in demon 2) and set the program to 
%%%% assume a 2nd-degree poly function for the baseline.
%% To do MEM including the removal of baseline
%==> PD_demo('BimodalSNR30MEMwP0bal');
%   (This performs Maximum Entropy calculations with considering the
%   existence of baseline in the data file. 'BimodalSNR30MEMwP0.pr0' is used as 
%   the seed values. The estimated baseline is stored in 'BimodalSNR30MEMbal.bal'.
%   The time-domain data after the removal of the baseline is stored in 
%   'BimodalSNR30MEMbal.S'.The solution P(r) is stored in both 
%   'BiomdalSNR30MEMbal.pr' and 'BimodalSNR30MEMbal.pr0'.)
%
%
%
%%%%
%%%% demo 4: This demo shows our recent development on TIKR.
%%%% We here show that by minimizing the negative portions in
%%%% the TIKR result P(r), TIKR actually can be used to simultaneously extract 
%%%% baseline from raw data and provide the best estimation for the distance 
%%%% distribution. The simulated signal vector, which contains the intra-
%%%% and inter-molecular interactions, is in 'BimodalSNR30expbal.dat'. It
%%%% is important to compare the result of demo 4 with the result of demo
%%%% 3. They don't necessarily be the same (since there are always some negative 
%%%% potions in the TIKR result), but should be similar. If the baseline in
%%%% raw experimental data has been properly removed in demo 3, MEM (demo 3) 
%%%% always shows a better result for P(r) than TIKR does as SNR is low.
%% To do TIKR with baseline correction:
%==> PD_demo('BimodalSNR30expbal');
%   (This command performs TIKR to recover P(r) from the given data file 
%   and simultaneously estimate the intermolecular interactions with the 
%   given function type. The estimated baseline is stored in 
%   'BimodalSNR30expbalTIKRbal.bal'. The time-domain data after the
%   baseline removal is stored in 'BimodalSNR30expbalTIKRbal.S'.The solution 
%   P(r) is stored in 'BiomdalSNR30expbalTIKRbal.pr'. The solution vector
%   P(r), whose negative elements are corrected to be positive, is stored
%   in the file 'BimodalSNR30expbalTIKRbal.pr0'.)
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% To plot the results of P(r):
%%%%    pl_PrLc('XXX.pr','pr');     or pl_PrLc('XXX.pr0','pr');
%%%% To plot the time-domain data S(t):
%%%%    pl_PrLc('XXX.S','st');      or pl_PrLc('XXX.dat','st');
%%%% To plot the results of L-curve:
%%%%    pl_PrLc('XXX.Lcurve','Lc',[rho eta]);
%%%%        here [rho eta] represent the x and y axis of the L-curve corner.
%%%%
%%%%
%%  Open the file, PD_demo.m, for the detailed discriptions of each
%%  commands and settings.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
warning off all
switch (casetype)
    case{'BimodalSNR30TKN'}
        inp1=[15 60];
    %The range of the recovered P(r) in the unit of Angstrom: [15 60]
        PD_TKN('BimodalSNR30.dat',inp1);
    %
    case{'BimodalSNR30MEMwP0'}
        inp1=[2 200 0.1 1];
    %Option: 2 (i.e. without considering baseline)
    %           See PD_MAXENT.m for details.
    %Number of the calculated regularization parameters (reg.): 200
    %The range of the reg. to search: [0.1 1]
        inp2=[15 60];
    %The range of the recovered P(r) in the unit of Angstrom: [15 60]
        PD_MAXENT('BimodalSNR30.dat','BimodalSNR30MEMwP0',inp1,inp2,...
            'pr0','BimodalSNR30TKN.pr0');
    %Perform Maximum Entropy calculations without considering baseline and
    % 1. Read in time-domain data, which is stored in 'BimodalSNR30.dat'.
    % 2. Use 'BimodalSNR30TKN.pr0' as initial P(r) for MEM calculation.
    % 3. Save the final result (e.g. P(r) vector) to the files, 'BimodalSNRMEMwP0.XX'.
    %Note: MEM calculation is a time-consuming process. It depends on how
    %many reg. parameters and the range you specify. As we suggested in our
    %MEM paper (JMR_177_2005_p184), user should perform several coarse-grained 
    %searches to narrow down the range before doing fine-grained search, e.g. 200
    %~ 500 reg. parameters.
    %
    %
    case{'BimodalSNR30MEMwP0bal'}
        inp1=[4 150 0.1 1.5];
    %Option: 4 (i.e. considering a 2nd-degree poly baseline in time-domain data)
    %Number of the calculated singular values: 150
    %The range of the singular values to search: [0.1 1.5]
        inp2=[15 60];
    %The range of the recovered P(r) in the unit of Angstrom: [15 60]
        PD_MAXENT('BimodalSNR30expbal.dat','BimodalSNR30MEMwP0bal',inp1,inp2,...
            'pr0','BimodalSNR30MEMwP0.pr0');
    %Perform Maximum Entropy calculations with baseline removal and
    % 1. Read in time-domain data, which is stored in 'BimodalSNR30expbal.dat'.
    % 2. Use 'BimodalSNR30MEMwP0.pr0' as initial values for P(r).
    % 3. Save the final result (i.e. P(r) vector) to the file, 'BimodalSNRMEMwP0bal.XX'.
    %
    %
    case{'BimodalSNR30expbal'}
        PD_TIKRbal('BimodalSNR30expbal.dat','poly3','no',[15 65]);
    %Perform TIKR and remove the baseline using the given function (e.g.
    %'poly3') simultaneously. The best estimate for the solution vector P(r)
    %is saved in 'BimodalSNR30expbalTIKRbal.pr'. The
    %'BimodalSNR30expbalTIKRbal.pr0' contains the solution P(r) after
    %having the negative values corrected. The time-domain data after the 
    %removal of the baseline is saved in 'BimodalSNR30expbalTIKRbal.S'. The 
    %estimated baseline is saved in 'BiomdalSNR30expbalTIKRbal.bal'.
    %
    %Type 'help PD_TIKRbal' for the usage of this function.
    otherwise
        error('invalid input');
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% IMPORTANT %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
% Note for further applications and for one who would like to use this DPD 
%package to recover P(r) from your real experimental data.
%
%1. Save your experimental time-domain data,S(t), to a data file (e.g. 'test.dat'), 
%which must be in ASCII format and is composed of two column vectors with the 
%precision of %10.5f. The first column is composed of time in the unit of
%micro sec. The 2nd column vector is composed of the values for S(t).
%
%2. Then perform the following three suggestions to obtain P(r)'s:
%   (a) Manually remove the baseline and then perform PD_TKN and then
%       PD_MAXENT (i.e. demo 1 and then demo 2).
%   (b) Seeding MEM calculations (i.e. PD_MAXENT) with the result obtained
%       in (a) and let the program determine a function for the baseline and 
%       the P(r). (i.e. demo 3)
%       We usually find that P(r) is refined in this step.
%   (c) Perform PD_TIKRbal (i.e. demo 4) and compare the obtained result with the 
%       results of (a) and (b). Note that when SNR of S(t) is low P(r) is always 
%       better recovered in (a) and (b) than in (c).
%
%
